@@ -4,11 +4,11 @@
 ## BGP neighbor group.
 ####
 
-package RouterBase::BGPGroup;
-use RouterBase::Atom;
+package IPDevice::RouterBase::BGPGroup;
+use IPDevice::RouterBase::Atom;
 use strict;
 use vars qw($VERSION @ISA);
-@ISA = qw(RouterBase::Atom RouterBase::BGPNeighbor);
+@ISA = qw(IPDevice::RouterBase::Atom IPDevice::RouterBase::BGPNeighbor);
 
 $VERSION = 0.01;
 
@@ -18,12 +18,12 @@ use constant FALSE => 0;
 
 =head1 NAME
 
-RouterBase::BGPGroup
+IPDevice::RouterBase::BGPGroup
 
 =head1 SYNOPSIS
 
- use RouterBase::BGPGroup;
- my $neigh = new RouterBase::BGPGroup;
+ use IPDevice::RouterBase::BGPGroup;
+ my $neigh = new IPDevice::RouterBase::BGPGroup;
  $neigh->set_name('Neighbor Name');
  $neigh->set_ip('192.168.0.2');
 
@@ -35,7 +35,7 @@ BGP neighbor group.
 =head1 CONSTRUCTOR AND METHODS
 
 This class provides all methods from
-L<RouterBase::BGPNeighbor|RouterBase::BGPNeighbor>.
+L<IPDevice::RouterBase::BGPNeighbor|IPDevice::RouterBase::BGPNeighbor>.
 
 =head1 COPYRIGHT
 
